==> react-formbuild-component-0.0.1.tgz: package/src/field/TextArea.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, Input, FormGroup, FormFeedback, FormText
} from 'reactstrap';
import {size, inRange} from 'lodash';

class TextareaField extends Component {
    static propTypes = {
        id: PropTypes.string.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string,
        value: PropTypes.string.isRequired,
        // eslint-disable-next-line
        onChange: PropTypes.func.isRequired,
        minLength: PropTypes.number,
        maxLength: PropTypes.number,
        helpText: PropTypes.bool,
        error: PropTypes.shape
    };

    static defaultProps = {
        label: null,
        maxLength: 250,
        minLength: 2,
        helpText: null,
        error: {
            status: null
        }
    };

    constructor(props) {
        super(props);
        this.state = {dirty: false};
    }

    static validateText(input, max = 50, min = 2) {
        return inRange(size(input), min, max + 1);
    }

    validateInput() {
        const {dirty} = this.state;
        if (!dirty) {
            return null;
        }
        const {value, maxLength, minLength} = this.props;
        return TextareaField.validateText(value, maxLength, minLength) ? 'success' : 'error';
    }

    handleChange({target}) {
        const {props} = this;
        if (props.value === target.value) {
            return;
        }
        this.setState({dirty: true});
        props.onChange({target});
    }

    render() {
        const styles = {
            noPadding: {
                margin: '0px',
                padding: '0px'
            },
            styleInvalid: {
                width: '100%',
                height: '0px',
                paddingTop: 0.25,
                fontSize: '80%',
                color: '#dc3545'
            },
            styleValid: {
                width: '100%',
                height: '0px',
                paddingTop: 0.25,
                fontSize: '80%',
                color: '#43a047'
            }
        }

        const {
            id,
            name,
            label,
            value,
            maxLength,
            minLength,
            helpText,
            error
        } = this.props;
        return (
            <FormGroup validationState={this.validateInput()}>
                <Label>{label}</Label>
                <Input
                    id={id}
                    name={name}
                    type="textarea"
                    componentClass="textarea"
                    value={value}
                    required
                    maxLength={maxLength}
                    minLength={minLength}
                    onChange={e => this.handleChange(e)}
                />
                <p style={error.status==='valid' ?  styles.styleValid : styles.styleInvalid}>
                    {error.message}
                </p>
                <FormText>{helpText}
                    {helpText && (<p>&nbsp;</p>)}
                    Quedan
                    &nbsp;
                    {maxLength - size(value)}
                    &nbsp;
                    caracter(es) disponibles.
                </FormText>
            </FormGroup>
        );
    }
}

export default TextareaField;

==> react-formbuild-component-1.1.0.tgz: package/src/field/TextArea.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, FormGroup, FormText, UncontrolledTooltip
} from 'reactstrap';
import {size, inRange} from 'lodash';
import {
    styleInvalid,
    styleValid,
    small,
    noPadding,
    flexR,
    padding,
    toolTipIcon,
    smallAlt
} from '../common/styles/index';
class TextareaField extends Component {
    static propTypes = {
        id: PropTypes.string.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string,
        value: PropTypes.string.isRequired,
        // eslint-disable-next-line
        onChange: PropTypes.func.isRequired,
        minLength: PropTypes.number,
        maxLength: PropTypes.number,
        helpText: PropTypes.bool,
        error: PropTypes.shape
    };

    static defaultProps = {
        label: null,
        maxLength: 250,
        minLength: 2,
        helpText: null,
        error: {
            status: null
        }
    };

    constructor(props) {
        super(props);
        this.state = {dirty: false};
    }

    static validateText(input, max = 50, min = 2) {
        return inRange(size(input), min, max + 1);
    }

    validateInput() {
        const {dirty} = this.state;
        if (!dirty) {
            return null;
        }
        const {value, maxLength, minLength} = this.props;
        return TextareaField.validateText(value, maxLength, minLength) ? 'success' : 'error';
    }

    handleChange({target}) {
        const {props} = this;
        if (props.value === target.value) {
            return;
        }
        this.setState({dirty: true});
        props.onChange({target});
    }

    render() {
        const {
            id,
            name,
            label,
            value,
            maxLength,
            minLength,
            helpText,
            error
        } = this.props;
        return (
            <FormGroup validationState={this.validateInput()}>
                <Label
                    style={{...small, ...noPadding, ...flexR,...padding}}>
                    <p
                        style={noPadding}>
                        {label+" "}
                    </p>
                    {helpText && (
                        <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}  id={'ref'+name}>
                            {String.fromCharCode(0x24D8)}
                        </p>
                    )}

                </Label>
                    id={id}
                    name={name}
                    type="textarea"
                    componentClass="textarea"
                    value={value}
                    required
                    maxLength={maxLength}
                    minLength={minLength}
                    onChange={e => this.handleChange(e)}
                />
                <p style={error.status==='valid' ?  styleValid : styleInvalid}>
                    {error.message}
                </p>
                <FormText>{helpText}
                    {helpText && (<p>&nbsp;</p>)}
                    Quedan
                    &nbsp;
                    {maxLength - size(value)}
                    &nbsp;
                    caracter(es) disponibles.
                </FormText>
                {helpText && (
                    <UncontrolledTooltip placement="right" target={'ref'+name}>
                        {helpText}
                    </UncontrolledTooltip>
                )}
            </FormGroup>
        );
    }
}

export default TextareaField;
